import os
from pathlib import Path

try:
    # Standard library in Python 3.8+
    import importlib.metadata as importlib_metadata
except ImportError:
    # The backport of the Python 3.8 stdlib module
    import importlib_metadata

VERSION_SCHEME = {
    "version_scheme": os.getenv("SCM_VERSION_SCHEME", "guess-next-dev"),
    "local_scheme": os.getenv("SCM_LOCAL_SCHEME", "node-and-date"),
}

root = Path(__file__).parent.parent
if (root / '.git').is_dir():
    # Use setuptools_scm when in a git repository
    from setuptools_scm import get_version

    __version__ = get_version(root, **VERSION_SCHEME)
else:
    # Get the version at runtime from PEP-0566 metadata using `importlib.metadata`
    # from the standard library or the `importlib_metadata` backport
    try:
        __version__ = importlib_metadata.version(__package__)
    except importlib_metadata.PackageNotFoundError:
        __version__ = None



import os
from setuptools import setup

VERSION_SCHEME = {}
VERSION_SCHEME["version_scheme"] = os.environ.get(
    "SCM_VERSION_SCHEME", "guess-next-dev"
)
VERSION_SCHEME["local_scheme"] = os.environ.get("SCM_LOCAL_SCHEME", "node-and-date")

setup(use_scm_version=VERSION_SCHEME)



from pkg_resources import get_distribution
import workflow_sandbox


def test_version():
    """Check version against `pkg_resources` from `setuptools`.
    """
    assert workflow_sandbox.__version__ == get_distribution('workflow_sandbox').version
